@@ -2,6 +2,7 @@ use strict;
 use warnings;
 
 use Async::Selector;
+use Async::Selector::Aggregator;
 
 {
     ## Level-triggered vs. Edge-triggered
@@ -111,6 +112,39 @@ print "==============\n";
     print "--------\n";
 
     $watcher_b->cancel();
-    $selector->trigger('A', 'B');        ## Nothing happens.
+    $selector->trigger('A', 'B');   ## Nothing happens.
+}
+
+print "=================\n";
+
+{
+    ## Watcher aggregator
+    
+    my $selector_a = Async::Selector->new();
+    my $selector_b = Async::Selector->new();
+    my $A = "";
+    my $B = "";
+    $selector_a->register(resource => sub { my $in = shift; return length($A) >= $in ? $A : undef });
+    $selector_b->register(resource => sub { my $in = shift; return length($B) >= $in ? $B : undef });
+    
+    my $watcher_a = $selector_a->watch(resource => 5, sub {
+        my ($watcher, %res) = @_;
+        print "A: $res{resource}\n";
+    });
+    my $watcher_b = $selector_b->watch(resource => 5, sub {
+        my ($watcher, %res) = @_;
+        print "B: $res{resource}\n";
+    });
+    
+    ## Aggregates the two watchers into $aggregator
+    my $aggregator = Async::Selector::Aggregator->new();
+    $aggregator->add($watcher_a);
+    $aggregator->add($watcher_b);
+    
+    ## This cancels both $watcher_a and $watcher_b
+    $aggregator->cancel();
+    
+    print("watcher_a: " . ($watcher_a->active ? "active" : "inactive") . "\n"); ## -> watcher_a: inactive
+    print("watcher_b: " . ($watcher_b->active ? "active" : "inactive") . "\n"); ## -> watcher_b: inactive
 }
 
