@@ -10,7 +10,7 @@ my $selector = Async::Selector->new();
 my $resource = "some text.";  ## 10 bytes
 
 $selector->register(resource_A => sub {
-    ## If $resource has more data than $threshold bytes, provide it.
+    ## If length of $resource is more than or equal to $threshold bytes, provide it.
     my $threshold = shift;
     return length($resource) >= $threshold ? $resource : undef;
 });
@@ -18,7 +18,7 @@ $selector->register(resource_A => sub {
 
 ## Watch the resource with a callback.
 $selector->watch(
-    resource_A => 20,  ## When the resource gets more than 20 bytes...
+    resource_A => 20,  ## When the resource gets more than or equal to 20 bytes...
     sub {              ## ... execute this callback.
         my ($watcher, %resource) = @_;
         print "$resource{resource_A}\n";
