@@ -17,11 +17,11 @@ Async::Selector - level-triggered resource observer like select(2)
 
 =head1 VERSION
 
-1.02
+1.03
 
 =cut
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 
 =pod
@@ -128,10 +128,11 @@ sub _check {
    my ($self, $watcher_id_or_watcher, @triggers) = @_;
    my %results = ();
    my $fired = 0;
-   my $watcher = $self->{watchers}{"$watcher_id_or_watcher"};
-   return 0 if !defined($watcher);
+   my $watcher_entry = $self->{watchers}{"$watcher_id_or_watcher"};
+   return 0 if not defined($watcher_entry);
+   my $watcher = $watcher_entry->{object};
    my %conditions = $watcher->conditions;
-   if($watcher->getCheckAll) {
+   if($watcher->get_check_all) {
        @triggers = $watcher->resources;
    }
    foreach my $res_key (@triggers) {
@@ -146,7 +147,7 @@ sub _check {
        }
    }
    return 0 if !$fired;
-   $watcher->call(%results);
+   $watcher_entry->{callback}->($watcher, %results);
    return 1;
 }
 
@@ -183,7 +184,7 @@ sub register {
    my ($self, %providers) = @_;
    my @error_keys = ();
    while(my ($key, $provider) = each(%providers)) {
-       if(!_isaCoderef($provider)) {
+       if(!_isa_coderef($provider)) {
            push(@error_keys, $key);
        }
    }
@@ -268,7 +269,7 @@ resources that are watched and available.
 
 =cut
 
-sub _isaCoderef {
+sub _isa_coderef {
     my ($coderef) = @_;
     return (defined($coderef) && defined(ref($coderef)) && ref($coderef) eq "CODE");
 }
@@ -277,19 +278,22 @@ sub watch_et {
     my $self = shift;
     my (%conditions, $cb);
     $cb = pop;
-    if(!_isaCoderef($cb)) {
+    if(!_isa_coderef($cb)) {
         croak "the watch callback must be a coderef.";
     }
     %conditions = @_;
     if(!%conditions) {
         return Async::Selector::Watcher->new(
-            undef, \%conditions, $cb
+            undef, \%conditions
         );
     }
     my $watcher = Async::Selector::Watcher->new(
-        $self, \%conditions, $cb
+        $self, \%conditions
     );
-    $self->{watchers}{"$watcher"} = $watcher;
+    $self->{watchers}{"$watcher"} = {
+        object => $watcher,
+        callback => $cb
+    };
     return $watcher;
 }
 
@@ -306,7 +310,7 @@ sub watch_lt {
 
 sub _wrapSelect {
     my ($self, $method, $cb, %conditions) = @_;
-    if(!_isaCoderef($cb)) {
+    if(!_isa_coderef($cb)) {
         croak "the select callback must be a coderef.";
     }
     my $wrapped_cb = sub {
@@ -319,7 +323,7 @@ sub _wrapSelect {
         }
     };
     my $watcher = $self->$method(%conditions, $wrapped_cb);
-    $watcher->setCheckAll(1);
+    $watcher->set_check_all(1);
     return $watcher->active ? "$watcher" : undef;
 }
 
@@ -339,7 +343,7 @@ sub cancel {
     my ($self, @watchers) = @_;
     foreach my $w (grep { defined($_) } @watchers) {
         next if not exists $self->{watchers}{"$w"};
-        $self->{watchers}{"$w"}->detach();
+        $self->{watchers}{"$w"}{object}->detach();
         delete $self->{watchers}{"$w"};
     }
     return $self;
@@ -420,11 +424,12 @@ try filtering the result (C<@watchers>) with L<Async::Selector::Watcher>'s C<res
 
 sub watchers {
     my ($self, @resources) = @_;
+    my @all_watchers = map { $_->{object} } values %{$self->{watchers}};
     if(!@resources) {
-        return values %{$self->{watchers}};
+        return @all_watchers;
     }
     my @affected_watchers = ();
-  watcher_loop: foreach my $watcher (values %{$self->{watchers}}) {
+  watcher_loop: foreach my $watcher (@all_watchers) {
         my %watch_conditions = $watcher->conditions;
         foreach my $res (@resources) {
             next if !defined($res);
